@@ -22,3 +22,12 @@ class SettingsPrismaCloudAPIComputeMixin:
             'put', 'api/v1/settings/registry',
             body_params=body
         )
+
+    def settings_host_auto_deploy_read(self):
+        return self.execute_compute('get', 'api/v1/settings/host-auto-deploy')
+
+    def settings_host_auto_deploy_write(self, body):
+        return self.execute_compute(
+            'post', 'api/v1/settings/host-auto-deploy',
+            body_params=body
+        )
